<script>
$(function () {
    $('#{{ chart.get_html_id }}').highcharts({
        chart: {
            type: "{{ chart.get_chart_type }}",
            options3d: {
                enabled: true,
                alpha: 45
            }
        },
        title: {
            text: "{{ chart.get_options.title }}"
        },
        plotOptions: {
            pie: {
                innerSize: 100,
                depth: 45
            }
        },
        series: [{
            name: "{{ chart.get_series_name }}",
            data: {{ chart.get_series_json|safe }}
        }]
    });
});
</script>
